from functools import cache
from io import BytesIO

import requests
from PIL import Image


@cache
def get_network_image(url):
    response = requests.get(url)
    response.raise_for_status()
    return Image.open(BytesIO(response.content))


def create_graphic(width, height, logo_height, bg_color, source_url, dest):
    img = Image.new("RGBA", (width, height), color=bg_color)

    logo = get_network_image(source_url).convert("RGBA")
    scale = logo_height / logo.size[1]
    logo_width = int(logo.size[0] * scale)
    logo = logo.resize((logo_width, logo_height), Image.LANCZOS)

    img.paste(logo, ((width - logo_width) // 2, (height - logo_height) // 2), logo)
    img.save(dest)
    print(f"Created {dest}")


def generate_play_store_assets(icon_bg, icon_url, wordmark_url):
    create_graphic(
        512,
        512,
        450,
        icon_bg,
        icon_url,
        "fastlane/metadata/android/en-US/images/icon.png",
    )
    create_graphic(
        1024,
        500,
        120,
        "#ffffff",
        wordmark_url,
        "fastlane/metadata/android/en-US/images/featureGraphic.png",
    )



import argparse

from clone.church import Church
from clone.graphics import generate_play_store_assets


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("church", help="Church slug")
    parser.add_argument("--android", action="store_true")
    args = parser.parse_args()

    church = Church(args.church)
    if args.android:
        generate_play_store_assets(
            icon_bg=church.icon_bg,
            icon_url=church.icon_url,
            wordmark_url=church.wordmark_url,
        )


if __name__ == "__main__":
    main()



import os
from dataclasses import dataclass
from functools import cached_property

import requests


@dataclass
class Church:
    slug: str

    @cached_property
    def configs(self):
        api_key = os.getenv("APOLLOS_API_KEY")
        if not api_key:
            raise ValueError("APOLLOS_API_KEY environment variable must be set")
        response = requests.get(
            f"https://apollos-cluster-production.herokuapp.com/api/config/{self.slug}",
            headers={"x-api-key": api_key},
        )
        response.raise_for_status()
        return response.json()

    icon_bg = property(
        lambda self: self.configs["APP.THEME"]["value"]["colors"]["primary"]
    )
    icon_url = property(lambda self: self.configs["APP.ICON_URL"]["value"])
    wordmark_url = property(lambda self: self.configs["APP.WORDMARK_URL"]["value"])
